@@ -12,6 +12,7 @@ import pickle
 import pandas as pd
 from typing import Union, Any, TextIO
 from .odb_visualizer import OdbVisualizer
+from .util import confirm
 from odbp import __version__
 
 
@@ -107,6 +108,14 @@ class CLIOptions():
         self.state_help: str = "Show the current state of the settings of the plotter"
         self.state_options_formatted: str = ", ".join(self.state_options)
 
+        self.abaqus_options: list[str] = ["abaqus", "abq", "abqpy"]
+        self.abaqus_help: str = "Select the Abaqus executable program to use to process .odb file"
+        self.abaqus_options_formatted: str = ", ".join(self.abaqus_options)
+
+        self.nodeset_options: list[str] = ["node", "nodes", "nodeset", "nodesets"]
+        self.nodeset_help: str = "Select the target nodeset (i.e., the named nodeset that contains all the data)"
+        self.nodeset_options_formatted: str = ", ".join(self.nodeset_options)
+
         self.help_options: list[str] = ["help", "use", "usage"]
         self.help_help: str = "Show this menu"
         self.help_options_formatted: str = ", ".join(self.help_options)
@@ -124,7 +133,9 @@ class CLIOptions():
                 len(self.title_label_options_formatted),
                 len(self.directory_options_formatted),
                 len(self.process_options_formatted),
-                len(self.angle_options_formatted)
+                len(self.angle_options_formatted),
+                len(self.abaqus_options_formatted),
+                len(self.nodeset_options_formatted),
                 )
 
 
@@ -147,6 +158,8 @@ class CLIOptions():
 {self.angle_options_formatted.ljust(self.longest_len)} -- {self.angle_help}
 {self.show_all_options_formatted.ljust(self.longest_len)} -- {self.show_all_help}
 {self.plot_options_formatted.ljust(self.longest_len)} -- {self.plot_help}
+{self.abaqus_options_formatted.ljust(self.longest_len)} -- {self.abaqus_help}
+{self.nodeset_options_formatted.ljust(self.longest_len)} -- {self.nodeset_help}
 {self.state_options_formatted.ljust(self.longest_len)} -- {self.state_help}"""
     )
 
@@ -184,8 +197,13 @@ def print_state(state: OdbVisualizer, user_options: UserOptions) -> None:
             "Image Title": f"{user_options.image_title if hasattr(user_options, 'image_title') else 'not set'}",
             "Image Label": f"{user_options.image_label if hasattr(user_options, 'image_label') else 'not set'}",
         },
+        {
+            "Target Parts": ",".join(state.parts) if hasattr(state, "parts") else "None Set",
+            "Target Nodeset": (state.nodesets[0] if len(state.nodesets) == 1 else "Error: Only specify multiple nodesets in extract mode") if hasattr(state, "nodesets") else "None Set"
+        },
         {
             "Data loaded into memory": f"{'Yes' if state.loaded else 'No'}",
+            "Abaqus Program": f"{state.abaqus_program if hasattr(state, 'abaqus_program') else 'not set'}",
         },
     ]
 
@@ -247,6 +265,10 @@ def process_input() -> "Union[tuple[OdbVisualizer, UserOptions], pd.DataFrame]":
     parser.add_argument("--low-time", help="Lower time limit, defaults to 0 (minimum possible)")
     parser.add_argument("--high-time", help="Upper time limit, defaults to infinity (max possible)")
 
+    parser.add_argument("-n", "--nodesets", help="Nodesets from which to Extract. Enter only one via CLI, use the .toml input file for a list")
+
+    parser.add_argument("-a", "--abaqus", help="Abaqus executable program to extract from .odb files")
+
     parser.add_argument("-V", "--view", type=view, help="Viewing Angle to show the plot in. Must either be a 3-tuple of integers or the name of a pre-defined view")
     
     parser.add_argument("-R", "--run", action="store_true", help="Run the plotter immediately, fail if all required parameters are not specified")
@@ -316,6 +338,17 @@ def generate_cli_settings(args: argparse.Namespace) -> "tuple[OdbVisualizer, Use
     cli_flags = {k: v for k, v in cli_flags.items() if v is not None}
     state, user_options = read_setting_dict(state, user_options, cli_flags)
 
+    if not os.path.exists(user_options.results_directory):
+        print(f"Directory {user_options.results_directory} does not exist. Creating it now.")
+        os.makedirs(user_options.results_directory)
+
+    if not state.hdf_processed:
+        if confirm(f"{state.odb_file_path} can be automatically converted to {state.hdf_file_path} with time sample {state.time_sample}", "Would you like to perfrom this conversion?", "yes"):
+            print(f"Converting {state.odb_file_path} file to .hdf5 file with name: {state.hdf_file_path}")
+            state.odb_to_hdf(state.hdf_file_path)
+        else:
+            print("You may perform this conversion later with the \"convert\" command")
+
     return (state, user_options)
 
 
@@ -381,7 +414,10 @@ def read_setting_dict(state: OdbVisualizer, user_options: UserOptions, settings_
             sys.exit(1)
 
     else:
-        hdf_source_dir = os.getcwd()
+        if not hasattr(user_options, "hdf_source_directory"):
+            hdf_source_dir = os.getcwd()
+        else:
+            hdf_source_dir = user_options.hdf_source_directory
 
     user_options.hdf_source_directory = hdf_source_dir
 
@@ -394,7 +430,10 @@ def read_setting_dict(state: OdbVisualizer, user_options: UserOptions, settings_
             sys.exit(1)
 
     else:
-        odb_source_dir = os.getcwd()
+        if not hasattr(user_options, "odb_source_directory"):
+            odb_source_dir = os.getcwd()
+        else:
+            odb_source_dir = user_options.odb_source_directory
 
     user_options.odb_source_directory = odb_source_dir
 
@@ -403,11 +442,10 @@ def read_setting_dict(state: OdbVisualizer, user_options: UserOptions, settings_
         results_dir = os.path.abspath(settings_dict["results_directory"])
 
     else:
-        results_dir = os.path.join(os.getcwd(), "results")
-
-    if not os.path.exists(results_dir):
-        print(f"Directory {results_dir} does not exist. Creating it now.")
-        os.makedirs(results_dir)
+        if not hasattr(user_options, "results_directory"):
+            results_dir = os.path.join(os.getcwd(), "results")
+        else:
+            results_dir = user_options.results_directory
 
     user_options.results_directory = results_dir
 
@@ -432,23 +470,7 @@ def read_setting_dict(state: OdbVisualizer, user_options: UserOptions, settings_
             state.set_time_sample(settings_dict["time_sample"])
 
         if "hdf" in settings_dict:
-            if os.path.exists(os.path.join(user_options.odb_source_directory, given_odb_file_path)):
-                if os.path.exists(os.path.join(os.getcwd(), given_odb_file_path)):
-                    if os.path.exists(given_odb_file_path):
-                        print(f"Error: The file {given_odb_file_path} already exists")
-                        sys.exit(1)
-
-                    else:
-                        odb_file_path = given_odb_file_path
-                else:
-                    odb_file_path = os.path.join(os.getcwd(), given_odb_file_path)
-            else:
-                odb_file_path = os.path.join(user_options.odb_source_directory, given_odb_file_path)
-
-            state.odb_file_path = odb_file_path
-            new_hdf_file_name: str = os.path.join(user_options.hdf_source_directory, settings_dict["hdf"])
-            print(f"Converting .odb file to .hdf5 file with name: {new_hdf_file_name}")
-            state.odb_to_hdf(new_hdf_file_name)
+            state.hdf_file_path = os.path.join(user_options.hdf_source_directory, settings_dict["hdf"])
 
     elif "hdf" in settings_dict:
         # ensure the file exists
@@ -600,8 +622,25 @@ def read_setting_dict(state: OdbVisualizer, user_options: UserOptions, settings_
     if "nodes" in settings_dict:
         state.set_nodes(settings_dict["nodes"])
 
-    if "nodesets" in settings_dict:
-        state.set_nodesets(settings_dict["nodesets"])
+    if hasattr(state, "nodesets"):
+        if "nodesets" in settings_dict:
+            nodesets = settings_dict["nodesets"]
+            if type(nodesets) is list:
+                state.set_nodesets(nodesets)
+            elif type(nodesets) is str:
+                state.set_nodesets([nodesets])
+    else:
+        nodesets = settings_dict.get("nodesets", ["ALL NODES"])
+        if type(nodesets) is list:
+            state.set_nodesets(nodesets)
+        elif type(nodesets) is str:
+            state.set_nodesets([nodesets])
+
+    if hasattr(state, "abaqus_program"):
+        if "abaqus" in settings_dict:
+            state.set_abaqus(settings_dict["abaqus"])
+    else:
+        state.set_abaqus(settings_dict.get("abaqus", "abaqus"))
 
     return (state, user_options)
 
@@ -627,7 +666,7 @@ def view(string: str) -> "dict[str, int]":
         elev: int
         azim: int
         roll: int
-        elev, azim, roll = map(int, formatted_string.split(","))
+        elev, azim, roll = [int(f) for f in formatted_string.split(",")]
         return {"elev": elev, "azim": azim, "roll": roll}
 
     except:
