@@ -6,12 +6,10 @@ Utility methods for odb_plotter
 
 from typing import Union
 
-DefaultType = Union[None, str]
-AnswerType = Union[tuple[str, str], tuple[str, str, str]]
 
-def confirm(message: str, confirmation: str, default: DefaultType = None) -> bool:
-    yes_vals: AnswerType = ("yes", "y")
-    no_vals: AnswerType = ("no", "n")
+def confirm(message: str, confirmation: str, default: "Union[None, str]" = None) -> bool:
+    yes_vals: Union[tuple[str, str], tuple[str, str, str]] = ("yes", "y")
+    no_vals: Union[tuple[str, str], tuple[str, str, str]] = ("no", "n")
     if isinstance(default, str):
         if default.lower() in yes_vals:
             yes_vals = ("yes", "y", "")
@@ -32,5 +30,3 @@ def confirm(message: str, confirmation: str, default: DefaultType = None) -> boo
             return False
         else:
             print("Error: invalid input")
-
-
